Action

Enum Action 

pub enum Action {
    SendFrame {
        stream_id: u64,
        fin_stream: bool,
        frame: Frame,
    },
    SendHeadersFrame {
        stream_id: u64,
        fin_stream: bool,
        literal_headers: bool,
        headers: Vec<Header>,
        frame: Frame,
    },
    StreamBytes {
        stream_id: u64,
        fin_stream: bool,
        bytes: Vec<u8>,
    },
    SendDatagram {
        payload: Vec<u8>,
    },
    OpenUniStream {
        stream_id: u64,
        fin_stream: bool,
        stream_type: u64,
    },
    ResetStream {
        stream_id: u64,
        error_code: u64,
    },
    StopSending {
        stream_id: u64,
        error_code: u64,
    },
    ConnectionClose {
        error: ConnectionError,
    },
    FlushPackets,
    Wait {
        wait_type: WaitType,
    },
}
An action which the HTTP/3 client should take.

The client iterates over a vector of said actions, executing each one sequentially. Note that packets will be flushed when said iteration has completed, regardless of if an Action::FlushPackets was the terminal action.

Variants



SendFrame

Send a [quiche::h3::frame::Frame] over a stream.

Fields

stream_id: u64
fin_stream: bool
frame: Frame


SendHeadersFrame

Send a HEADERS frame over a stream.

Fields

stream_id: u64
fin_stream: bool
literal_headers: bool
headers: Vec<Header>
frame: Frame


StreamBytes

Send arbitrary bytes over a stream.

Fields

stream_id: u64
fin_stream: bool
bytes: Vec<u8>


SendDatagram

Send a DATAGRAM frame.

Fields

payload: Vec<u8>


OpenUniStream

Open a new unidirectional stream.

Fields

stream_id: u64
fin_stream: bool
stream_type: u64


ResetStream

Send a RESET_STREAM frame with the given error code.

Fields

stream_id: u64
error_code: u64


StopSending

Send a STOP_SENDING frame with the given error code.

Fields

stream_id: u64
error_code: u64


ConnectionClose

Send a CONNECTION_CLOSE frame with the given ConnectionError.

Fields



FlushPackets



Wait

Wait for an event. See WaitType for the events.

Fields

wait_type: WaitType