pub enum ExpectedStreamSendResult {
Ok,
OkExact(usize),
Error(Error),
}Expand description
Expected result from a stream_send operation.
Variants
Ok
Expect success with any number of bytes written.
OkExact(usize)
Expect success with exactly the specified number of bytes written.
Error(Error)
Expect the operation to fail with the specified error.