send_headers_frame_literal_with_expected_result

Function send_headers_frame_literal_with_expected_result 

pub fn send_headers_frame_literal_with_expected_result(
    stream_id: u64,
    fin_stream: bool,
    headers: Vec<Header>,
    expected_result: ExpectedStreamSendResult,
) -> Action
Convenience to convert between header-related data and a Action::SendHeadersFrame. Unlike send_headers_frame, this version encodes the headers literally as they are provided, not converting the header names to lower-case.